@@ -8,11 +8,11 @@ Text::Editor::Easy::Comm - Thread communication mecanism of "Text::Editor::Easy"
 
 =head1 VERSION
 
-Version 0.44
+Version 0.46
 
 =cut
 
-our $VERSION = '0.44';
+our $VERSION = '0.46';
 
 =head1 SYNOPSIS
 
@@ -279,9 +279,9 @@ use strict;
 require Exporter;
 our @ISA = ("Exporter");
 
-#  qw ( execute_this_task anything_for_me get_task_to_do ask2 verify_model_thread respond simple_context_call verify_graphic verify_motion_thread reference_event_conditions have_task_done);
+#  qw ( execute_this_task anything_for_me get_task_to_do ask2 verify_model_thread respond simple_context_call verify_graphic have_task_done);
 our @EXPORT =
-  qw ( execute_this_task anything_for_me anything_for ask2 get_task_to_do reference_event_conditions have_task_done);
+  qw ( execute_this_task anything_for_me anything_for ask2 get_task_to_do have_task_done);
 
 our @EXPORT_OK =
   qw(ask_named_thread)
@@ -306,7 +306,7 @@ share(%server_queue_by_tid);
 my %stop_dequeue_server_queue;
 share(%server_queue_by_tid);
 
-# indfini tant que l'objet n'est pas correctement fini, 1 sinon (entre, unique_ref)
+# indfini tant que l'objet n'est pas correctement fini, 1 sinon (entre, id)
 my %synchronize; 
 share(%synchronize);
 
@@ -557,18 +557,6 @@ sub get_task_to_do {
 my %method;   # Permet de trouver le serveur qui gre une mthode diteur donne
 share(%method);
 
-sub get_ref {
-    my ($self) = @_;
-
-    return $com_unique{ refaddr $self };
-}
-
-sub set_ref {
-    my ( $self, $ref ) = @_;
-
-    return if ( !defined $ref );
-    $com_unique{ refaddr $self } = $ref;
-}
 
 my $call_order = 0;
 
@@ -577,14 +565,14 @@ sub ask2 {
 
     my $server_tid;
 
-    my $unique_ref;
+    my $id;
     if ( ! ref($self) ) {    # Appel d'une mthode de classe
-        $unique_ref = '';
+        $id = '';
     }
     else {
-       $unique_ref = $com_unique{ refaddr $self };
+       $id = $com_unique{ refaddr $self };
 
-        if ( !defined $unique_ref ) {
+        if ( !defined $id ) {
             print STDERR "No reference found for object $self, can't manage this instance of ", ref($self), "\n";
             return;
         }
@@ -592,9 +580,9 @@ sub ask2 {
     my $client_tid = threads->tid;
 
     my $tid;
-    if ($unique_ref) {
+    if ($id) {
         my $hash_ref = $get_tid_from_instance_method{$method};
-        $tid = $hash_ref->{$unique_ref};
+        $tid = $hash_ref->{$id};
 
         if ( !defined $tid ) {
             $tid = $hash_ref->{ ref($self) };
@@ -604,7 +592,7 @@ sub ask2 {
             if ( defined $tid and $tid =~ /\D/ ) {
                 print DBG "Trouv un appel nomm : mthode $method, nom $tid\n";
                 my $hash_ref = $get_tid_from_thread_name{$tid};
-                $tid = $hash_ref->{$unique_ref};
+                $tid = $hash_ref->{$id};
                 print DBG "TID de l'appel nomm : $tid\n";
             }
         }
@@ -629,12 +617,12 @@ sub ask2 {
          print DBG "TID dfini pour mthode $method... : $tid\n";
         $server_tid = $tid;
         # Following call not to be shown in trace
-        return new_ask( $self, $method, $unique_ref, $client_tid, $server_tid, @data );
+        return new_ask( $self, $method, $id, $client_tid, $server_tid, @data );
     }
     # La mthode s'excute dans le contexte du thread client appelant
     print DBG "La mthode $method n'est pas gre par un thread serveur\n";
 
-    my $sub = $method{ $unique_ref . ' ' . $method };
+    my $sub = $method{ $id . ' ' . $method };
     if ( !defined $sub ) {
 
         print DBG "Recherche de la mthode 'shared' $method...\n";
@@ -642,12 +630,12 @@ sub ask2 {
 
         if ( !defined $sub ) {
              print DBG "Impossible de trouver la sub pour la mthode $method...\n";
-             print STDERR "Can't handle method $method for object $self ($unique_ref)\n";
+             #print STDERR "Can't handle method $method for object $self ($id)\n";
              return;
         }
     }
     else {
-        print DBG "La mthode $method est spcifique  la rfrence $unique_ref\n";
+        print DBG "La mthode $method est spcifique  la rfrence $id\n";
     }
     my $sub_ref = eval "\\&$sub";
     # Following call not to be shown in trace
@@ -655,7 +643,7 @@ sub ask2 {
 }
 
 sub new_ask {
-    my ( $self, $method, $unique_ref, $client_tid, $server_tid, @data ) = @_;
+    my ( $self, $method, $id, $client_tid, $server_tid, @data ) = @_;
 
     if ( $method eq 'save_info_on_file' ) {
         print "APPEL save_info_on... @_\n";
@@ -691,7 +679,7 @@ sub new_ask {
 #        print DBG "\tCALL_ID     : $call_id\n";
 
         return execute_task( 'sync', $self_server, $method, $call_id,
-            $unique_ref || $self,
+            $id || $self,
             $context, @data );
     }
 
@@ -713,15 +701,15 @@ sub new_ask {
             push @calls, [ $pack, $file, $line ];
         }
         my @call_params = (
-            $call_id, $server_tid,    $method, $unique_ref,
+            $call_id, $server_tid,    $method, $id,
             $context, gettimeofday(), @calls
         );
         Text::Editor::Easy->trace_call(@call_params);
     }
 
-    my $message = dump ( $method, $call_id, $unique_ref || $self, $context, @data );
+    my $message = dump ( $method, $call_id, $id || $self, $context, @data );
 
-    my $reference_sent = $unique_ref || $self;
+    my $reference_sent = $id || $self;
 
     while ( $queue_by_tid{$client_tid}->pending ) {
         print DBG "   PROBLEME appel avec file perso dj renseigne...\n";
@@ -771,25 +759,25 @@ sub ask_thread {
     my ( $self, $method, $server_tid, @data ) = @_;
 
     # En commun avec ask2 :  simplifier !!!
-    my $unique_ref;
+    my $id;
     if ( $self eq 'Text::Editor::Easy' or $self eq 'Text::Editor::Easy::Async' )
     {    # Appel d'une mthode de classe
-        $unique_ref = '';
+        $id = '';
     }
     else {
-        $unique_ref = $com_unique{ refaddr $self };
+        $id = $com_unique{ refaddr $self };
 
-        if ( !defined $unique_ref ) {
+        if ( !defined $id ) {
             print STDERR "ask_thread : no reference found for object $self\n";
             return;
         }
     }
     
-# Attention, la premire donne de la fonction est $unique_ref || $self ==> cad la rfrence avec laquelle la mthode de thread
+# Attention, la premire donne de la fonction est $id || $self ==> cad la rfrence avec laquelle la mthode de thread
 # a t appele
     # Following call not to be shown in trace
     return new_ask( 
-        $self, $method, $unique_ref, threads->tid, $server_tid, $unique_ref || $self, @data
+        $self, $method, $id, threads->tid, $server_tid, $id || $self, @data
     );
 }
 
@@ -797,22 +785,22 @@ sub ask_named_thread {
     my ( $self, $method, $server, @data ) = @_;
 
     # En commun avec ask2 :  simplifier !!!
-    my $unique_ref;
+    my $id;
     if ( $self eq 'Text::Editor::Easy' or $self eq 'Text::Editor::Easy::Async' )
     {    # Appel d'une mthode de classe
-        $unique_ref = '';
+        $id = '';
     }
     elsif ( ref $self ) {
-        $unique_ref = $com_unique{ refaddr $self };
+        $id = $com_unique{ refaddr $self };
 
-        if ( !defined $unique_ref ) {
+        if ( !defined $id ) {
             print STDERR "ask_named_thread : no reference found for object $self\n";
             return;
         }
     }
     else {
         my $async;
-        ( $unique_ref, $async ) = split ( /:/ ,$self);
+        ( $id, $async ) = split ( /:/ ,$self);
         if ( defined $async ) {
             $self = 'Text::Editor::Easy::Async';
         }
@@ -823,19 +811,19 @@ sub ask_named_thread {
     my $server_tid = $server;
     if ( $server =~ /\D/ ) {
         my $hash_ref = $get_tid_from_thread_name{$server};
-        $server_tid = $hash_ref->{$unique_ref};
+        $server_tid = $hash_ref->{$id};
         #print "Ask named thread, trouv pour server $server tid $server_tid|@data\n";
     }
     
-# Attention, la premire donne de la fonction est $unique_ref || $self ==> cad la rfrence avec laquelle la mthode de thread
+# Attention, la premire donne de la fonction est $id || $self ==> cad la rfrence avec laquelle la mthode de thread
 # a t appele
-    return new_ask( $self, $method, $unique_ref, threads->tid, $server_tid, @data );
+    return new_ask( $self, $method, $id, threads->tid, $server_tid, @data );
 }
 
 sub create_thread {
     my ( undef, @param ) = @_;
 
-    #print "Dans create_thread : $unique_ref\n" if ( defined $unique_ref );
+    #print "Dans create_thread : $id\n" if ( defined $id );
 
     my $thread = threads->new( \&verify_server_queue_and_wait, @param );
 
@@ -943,17 +931,15 @@ sub verify_model_thread {
         $method{'create_new_server'}    = ('create_new_server');
         $method{'create_client_thread'} =
           ('create_client_thread');
-        $method{'get_ref'}              = ('get_ref');
+        $method{'id'}              = ('id');
         $method{'set_synchronize'}  = ('set_synchronize');
         $method{'get_synchronized'} = ('get_synchronized');
-        $method{'redirect'}         = ('redirect');
-        $method{'transform_hash'}   = ('transform_hash');
-        $method{'set_ref'}          = ('set_ref');
 
         $method{'create_thread'} = ('shared_thread:Text::Editor::Easy::Comm');
         $method{'add_method'}    = ('add_method');
         $method{'ask_thread'}    = ('ask_thread');
         $method{'ask_named_thread'}    = ('ask_named_thread');
+        $method{'get_from_id'}    = ('get_from_id');
         create_data_thread();
     }
     # Now that everything has been created, we can trace the 'new' call
@@ -1085,6 +1071,7 @@ sub create_data_thread {
                 'trace_end_of_user_event',
                 'trace_eval',
                 'tell_length_slash_n',
+                'data_zone',
             ],
             'object' => [],
             'init'   => ['Text::Editor::Easy::Data::init_data'],
@@ -1106,7 +1093,8 @@ sub verify_graphic {
 
     #print "verify graphic : force_resize $force_resize\n";
     my $ref = refaddr $editor;
-    $com_unique{$ref} = $ref;
+    set_ref ( $editor, $ref );
+    #$com_unique{$ref} = $ref;
 
     my $queue = $server_queue_by_tid{0};
 
@@ -1161,7 +1149,6 @@ sub verify_graphic {
                     'width',
                     'height',
 
-                    #    'reference_zone_event', class method
                     'abstract_size',
 
                     'new_editor',
@@ -1225,6 +1212,7 @@ sub verify_graphic {
                     'growing_check',
                     'set_at_end',
                     'unset_at_end',
+                    #'zone',
 
                     # Event generation
                     'key_press',
@@ -1257,7 +1245,7 @@ sub verify_graphic {
             {
                 'package' => 'Text::Editor::Easy::Abstract',
                 'method'  => [ 
-                        'reference_zone_event',
+                        'reference_zone_events',
                         'exit', 
                         'abstract_join', 
                         'manage_event', 
@@ -1302,6 +1290,54 @@ sub verify_graphic {
     }
 }
 
+my %editor;
+
+sub set_ref {
+    my ( $self, $ref ) = @_;
+
+    return if ( !defined $ref );
+    $com_unique{ refaddr $self } = $ref;
+    
+    print DBG "Dans set_ref, on fixe la ref $ref pour l'diteur $self|", refaddr $self, "\n";
+    print DBG "...tid = ", threads->tid, "\n";
+
+    if ( ref $self eq 'Text::Editor::Easy' ) {
+        #print "Danger, Async rfrenc !\n";
+        $editor{ threads->tid . '_' . $ref } = $self;        
+    }
+}
+
+sub id {
+    my ($self) = @_;
+
+    return $com_unique{ refaddr $self };
+}
+
+sub get_from_id {
+    my ( $self, $id ) = @_;
+    
+    # Mthode de classe mais peut tre appele avec une instance (self non utilise)
+    return if ( ! $id );
+    
+    my $editor = $editor{ threads->tid . '_' . $id};
+    
+    if ( $editor ) {
+        #print "Editeur $editor dfini pour l'id $id, refaddr ", refaddr $editor, "| tid = ", threads->tid, "\n";
+        return $editor;
+    }
+    
+    #  Tester la validit de $id (en controlant %com_unique) ? ... analyser les consquences possibles de la non vrification.
+ 
+    $editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
+    
+    print DBG "On fixe a id = $id le nouvel diteur editor = $editor| refaddr.. = ", refaddr $editor, "\n";
+    
+    $com_unique{ refaddr $editor } = $id;
+    $editor{ threads->tid . '_' . $id} = $editor;
+    
+    return $editor;
+}
+
 sub new_editor {
     my ( $ref, $hash_ref ) = @_;
 
@@ -1309,7 +1345,8 @@ sub new_editor {
 
     #print "\tREF $ref\n\tREF_HASH $hash_ref\n\tRESTE $reste\n";
     my $editor = bless \do { my $anonymous_scalar }, 'Text::Editor::Easy';
-    $com_unique{ refaddr $editor } = $ref;
+    set_ref( $editor, $ref );
+    #$com_unique{ refaddr $editor } = $ref;
 
     print DBG "Dans new_editor, avant appel Abstract new\n";
     my $object = Text::Editor::Easy::Abstract->new( $hash_ref, $editor, $ref );
@@ -1324,22 +1361,22 @@ sub create_client_thread {
     my ( $self, $sub_name, $package ) = @_;
 
     my $ref        = refaddr $self;
-    my $unique_ref = $com_unique{$ref};
-    if ( !$unique_ref ) {
+    my $id = $com_unique{$ref};
+    if ( !$id ) {
         print STDERR "create_client_thread : no reference found for object $self\n";
         return;
     }
 
-#print "... mthode de cration d'un thread client : $unique_ref\n";
+#print "... mthode de cration d'un thread client : $id\n";
 # Cette mthode de top bas niveau devrait tre masque de l'interface : juste un exemple de thread "shared" entre les diteurs
     $package = 'main' if ( !defined $package );
-    my $tid = create_thread( $self, $unique_ref, $package );
+    my $tid = create_thread( $self, $id, $package );
 
     #print "TID = $tid\n";
     my $queue = $server_queue_by_tid{$tid};
 
     my $message =
-      dump ( "${package}::$sub_name", threads->tid, "S", $unique_ref,
+      dump ( "${package}::$sub_name", threads->tid, "S", $id,
         $package );
     $queue->enqueue($message);
 
@@ -1370,7 +1407,7 @@ sub thread_generator {
 }
 
 sub verify_server_queue_and_wait {
-    my ( $unique_ref, $package ) = @_;
+    my ( $id, $package ) = @_;
 
     my $tid = threads->tid;
 
@@ -1401,18 +1438,19 @@ sub verify_server_queue_and_wait {
         #print "Utilisation du thread $tid et appel $what ($sub_ref)\n";
 
       # Appel seulement lorsque la file d'attente client existe (faire un while)
-        if ( defined $unique_ref ) {    # Thread ddi  un diteur
+        if ( defined $id ) {    # Thread ddi  un diteur
             my $editor;
-            if ( $unique_ref =~ /\D/ ) {
+            if ( $id =~ /\D/ ) {
 
                 # Class call
-                $editor = $unique_ref;
+                $editor = $id;
             }
             else {
                 $editor = bless \do { my $anonymous_scalar },
                   "Text::Editor::Easy";
+                set_ref( $editor, $id );
 
-                $com_unique{ refaddr $editor } = $unique_ref;
+                #$com_unique{ refaddr $editor } = $id;
             }
 
             #print "PARAM @param|", scalar(@param), "\n";
@@ -1437,197 +1475,18 @@ sub verify_server_queue_and_wait {
 sub set_synchronize {
     my ($self) = @_;
 
-    my $unique_ref = $com_unique{ refaddr $self };
-    $synchronize{$unique_ref} = 1;
+    my $id = $com_unique{ refaddr $self };
+    $synchronize{$id} = 1;
 }
 
 sub get_synchronized {
     my ($self) = @_;
 
-    my $unique_ref = $com_unique{ refaddr $self };
-    while ( !$synchronize{$unique_ref} ) {
+    my $id = $com_unique{ refaddr $self };
+    while ( !$synchronize{$id} ) {
     }
 }
 
-my %redirect = do "Text/Editor/Easy/Data/Events.pm";
-
-my $motion_thread : shared;
-
-sub verify_motion_thread {
-    my ( $unique_ref, $hash_ref ) = @_;
-
-    my $motion_thread_useful = 0;
-    my %event                = ();
-
-    #print "DANS VERIFY MOTION THREAD...$unique_ref|$motion_ref\n";
-    #print DBG "Taille de \%event $unique_ref 0 :", scalar(%event), "\n";
-    for my $event ( keys %$hash_ref ) {
-
-        #print DBG "HASH_REF pour : $event ...\n";
-        if ( $redirect{$event} ) {
-
-            #print DBG "$event est un vnement !\n";
-            my $event_ref = $hash_ref->{$event};
-            my $mode = $event_ref->{'mode'};
-            if ( defined $mode and $mode eq 'async' ) {
-
-                #print DBG "Il est asynchrone !!!\n";
-                $motion_thread_useful = 1;
-                $event{$event} = $event_ref;
-
-                #print DBG "Event trouv pour $unique_ref : $event ...\n";
-            }
-
-            #print "COND CREATION $event $event_ref->{'only'} \n";
-            #$redirect_condition{$event}{$unique_ref} = $event_ref->{'only'};
-        }
-    }
-
-    #print DBG "Taille de \%event $unique_ref :", scalar(%event), "\n";
-    
-    #if ( !defined $motion_thread and $motion_thread_useful ) {
-    if ( ! defined $motion_thread ) {
-        #print "Je cre le motion thread\n";
-
-        my $tid = Text::Editor::Easy->create_new_server(
-            {
-                'use'     => 'Text::Editor::Easy::Motion',
-                'package' => 'Text::Editor::Easy::Motion',
-                'methods' => [ 'reference_event', 'manage_events' ],
-                'object'  => {},
-                'name' => 'Motion',
-            }
-        );
-
-        my $queue = $server_queue_by_tid{$tid};
-        while ( !$queue ) {
-            $queue = $server_queue_by_tid{$tid};
-        }
-
-        # Cration multi-thread possible : on n'est pas seul...
-        $motion_thread = $tid if ( !defined $motion_thread );
-        
-        if ( $motion_thread != $tid ) {
-    # Le motion_thread a t cr par un autre diteur, il faut liminer le notre
-            my $message = dump (undef);
-            $queue->enqueue($message);
-
-            threads->object($tid)->join();
-
-            # Suppression des queue (ou recyclage ?)  faire
-        }
-    }
-
-# Demande asynchrone de prise en compte de sub motion : cette demande ne devrait pas tre asynchrone !!
-#print "TID DU MOTION THREAD $motion_thread\n";
-#print DBG "Taille de \%event $unique_ref 2 :", scalar(%event), "\n";
-    for my $event ( keys %event ) {
-
-        print DBG "Avant call de reference event $unique_ref : $event ...\n";
-
-     #Text::Editor::Easy::Async->ask2( 'reference_event' . ' ' . $motion_thread,
-     #    $event, $unique_ref, $event{$event} );
-
-        Text::Editor::Easy->reference_event( $event, $unique_ref,
-            $event{$event} );
-    }
-}
-
-my %redirect_condition;
-
-sub reference_event_conditions {    # Toujours excut dans le thread 0
-    my ( $unique_ref, $hash_ref ) = @_;
-
-    my %event;
-    my $motion_thread_useful;
-
-    #print "DANS VERIFY MOTION THREAD...$unique_ref|$motion_ref\n";
-    for my $event ( keys %$hash_ref ) {
-        if ( $redirect{$event} ) {
-            my $event_ref = $hash_ref->{$event};
-            if ( $event_ref->{'mode'} eq 'async' ) {
-                $motion_thread_useful = 1;
-                $event{$event} = $event_ref;
-            }
-
-            #print "COND CREATION $event $event_ref->{'only'} \n";
-            $redirect_condition{$event}{$unique_ref} = $event_ref->{'only'};
-        }
-    }
-}
-
-sub redirect {
-    my ( $self, $method, $abstract_ref, $hash_ref ) = @_;
-
-    my $ref = $com_unique{ refaddr $self};
-    if ( ref($method) ne 'CODE' ) {
-
-        print DBG "Appel asynchrone avec la mthode $method, $ref...\n";
-        if ( my $condition = $redirect_condition{$method}{$ref} ) {
-            my $origin     = $hash_ref->{'origin'};
-            my $sub_origin = $hash_ref->{'sub_origin'};
-
-            print DBG "CONDITION : $condition\n\t$origin\n\t$sub_origin\n";
-            if ( eval "$condition" ) {
-
-                print DBG "\tCondition positive : $@\n";
-
-                print( "dans REDIRECT de cOMM : zone = ",
-                    $hash_ref->{'zone'}, "\n" )
-                  if ( defined $hash_ref->{'zone'} );
-
-                Text::Editor::Easy::Async->manage_events( $method, $ref,
-                    $hash_ref );
-
-                return;    # Garder un context Void sur "manage_events"
-            }
-            else {
-
-                print DBG "\tFAUX (condition) : $@\n";
-            }
-        }
-        else {             # Pas de condition, on excute tout le temps
-            return if ( !defined $motion_thread );
-
-            #Text::Editor::Easy::Async->ask2( 'manage_events ' . $motion_thread,
-            #    $method, $ref, $hash_ref );
-
-            Text::Editor::Easy::Async->manage_events( $method, $ref,
-                $hash_ref );
-
-            return;    # Garder un context Void sur "manage_events"
-        }
-    }
-    else {
-        eval {
-            $method->(
-                $self, transform_hash( $self, $abstract_ref, $hash_ref )
-            );
-        };
-        print DBG $@ if ($@);
-    }
-}
-
-sub transform_hash {
-    my ( $editor, $abstract_ref, $hash_ref ) = @_;
-
-    my $ref_line = $hash_ref->{'line'};
-    if ( defined $ref_line ) {
-        my $line = Text::Editor::Easy::Line->new( $editor, $ref_line, );
-        $hash_ref->{'line'} = $line;
-    }
-    my $ref_display = $hash_ref->{'display'};
-    if ( defined $ref_display ) {
-        my $display =
-          Text::Editor::Easy::Display->new( $editor, $ref_display, );
-        $hash_ref->{'display'} = $display;
-    }
-
-    #print "Dans transform hash\n";
-    #print "Fin de line size\n";
-    return $hash_ref;
-}
-
 sub init_server_thread {
     my ( $self_caller, $options_ref ) = @_;
 
@@ -1935,7 +1794,7 @@ sub add_method {
 
         # instance method (adding it for only one Text::Editor::Easy object)
         print "Adding method $method to object $self\n";
-        $key = get_ref($self) . ' ' . $method;
+        $key = id($self) . ' ' . $method;
     }
     else {
 
@@ -1953,24 +1812,26 @@ sub create_new_server {
     my $tab_methods_ref = $options_ref->{'methods'};
     my $self_server     = $options_ref->{'object'};
 
-    #print DBG "Dans create_new_server $package $self_server\n";
+    #print DBG "Dbut create_new_server \$self $self, mthodes : ", @$tab_methods_ref, "\n";
 
-    my $unique_ref;
+    my $id = undef;
     if ( defined $self and ref($self) ) {
+        #print DBG "Dans create_new_server, thread d'instance 1 : ref \$self = ", ref($self), "\n";
+        
         my $ref = refaddr $self;
-        $unique_ref = $com_unique{$ref};
+        $id = $com_unique{$ref};
 
-        if ( !defined $unique_ref ) {
+        if ( !defined $id ) {
             print STDERR "create_new_server : no reference found for object $self\n";
             return;
         }
     }
     my $self_caller;
-    if ( !$unique_ref ) {
+    if ( !$id ) {
         $self_caller = $self;    # Class call => shared thread expected
     }
     else {
-        $self_caller = $unique_ref;
+        $self_caller = $id;
     }
     my $tid = threads->tid;
     if ( !$options_ref->{'do_not_create'} ) {
@@ -1979,14 +1840,13 @@ sub create_new_server {
     {
         my $key;
         my $name     = $options_ref->{'name'};
-        if ($unique_ref) {       # Appel d'instance ($self est un objet)
-
+        if ( $id ) {       # Appel d'instance ($self est un objet)
             my $class    = ref $self;
             
             my $name_tid = $name || $tid;
             $name_tid = $tid if ( $options_ref->{'put_tid'} );
             if ( $options_ref->{'specific'} ) {
-                $key = $unique_ref;
+                $key = $id;
             }
             else {
                 $key = $class;
@@ -1998,7 +1858,7 @@ sub create_new_server {
                 if ( defined $hash_ref ) {
                     %hash = %{$hash_ref};
                 }
-                $hash{$unique_ref}               = $tid;
+                $hash{$id}               = $tid;
                 $get_tid_from_thread_name{$name} = \%hash;
             }
             for my $method ( @{$tab_methods_ref} ) {
@@ -2151,27 +2011,27 @@ sub get_tid {
 }
 
 sub get_tid_from_name_and_instance {
-    my ( $unique_ref, $name ) = @_;
+    my ( $id, $name ) = @_;
         
-    if ( $unique_ref eq 'Text::Editor::Easy' or $unique_ref eq 'Text::Editor::Easy::Async' )
+    if ( $id eq 'Text::Editor::Easy' or $id eq 'Text::Editor::Easy::Async' )
     {    # Appel d'une mthode de classe
-        $unique_ref = '';
+        $id = '';
     }
-    elsif ( ref $unique_ref ) {
-        $unique_ref = $com_unique{ refaddr $unique_ref };
+    elsif ( ref $id ) {
+        $id = $com_unique{ refaddr $id };
 
-        if ( !defined $unique_ref ) {
-            print STDERR "get_tid_from_name_and_instance : no reference found for object $unique_ref\n";
+        if ( !defined $id ) {
+            print STDERR "get_tid_from_name_and_instance : no reference found for object $id\n";
             return;
         }
     }
 
     my $hash_ref = $get_tid_from_thread_name{$name};
-    my $server_tid = $hash_ref->{$unique_ref};
+    my $server_tid = $hash_ref->{$id};
     if ( defined $server_tid ) {
         return $server_tid;
     }
-    if ( defined $unique_ref ) {
+    if ( defined $id ) {
         $server_tid = $hash_ref->{''};
     }
     return $server_tid;
@@ -2230,8 +2090,6 @@ ask_thread requires to know the tid of a thread. But an arbitrary number is not
 
 =head2 get_message_for
 
-=head2 get_ref
-
 Return the reference (unique) of a Text::Editor::Easy instance.
 
 =head2 get_synchronized
@@ -2253,12 +2111,8 @@ thread communication.
 Quick mecanism to display or to hide debug information from a package / thread. Don't need to remove
 all the "print DBG" everywhere.
 
-=head2 redirect
-
 =head2 ref
 
-=head2 reference_event_conditions
-
 =head2 respond
 
 =head2 set_ref
@@ -2277,16 +2131,12 @@ all the "print DBG" everywhere.
 
 Every AUTOLOAD calls are traced. Still some important methods (instance creation, thread creation, ...) are not yet traced. To be done.
 
-=head2 transform_hash
-
 =head2 untie_print
 
 =head2 verify_graphic
 
 =head2 verify_model_thread
 
-=head2 verify_motion_thread
-
 =head2 verify_server_queue_and_wait
 
 =head1 AUTHOR
