@@ -9,11 +9,11 @@ Text::Editor::Easy::Events - Manage events linked to user code : specific code i
 
 =head1 VERSION
 
-Version 0.44
+Version 0.46
 
 =cut
 
-our $VERSION = '0.44';
+our $VERSION = '0.46';
 
 =head1 INTRODUCTION
 
@@ -98,15 +98,27 @@ name of the events :
 
 =item *
 
-'clic'
+'clic', modifier keys (alt, ctrl and/or shift) can be used
 
 =item *
 
-'motion' is not yet integrated in this new management !
+'motion', mouse move, modifier keys can be used
+
+=item *
+
+'drag', mouse move with left mouse button pressed, modifier keys can be used
+
+=item *
+
+'change', happens when the text of the editor is changed (text added, deleted or replaced).
+
+=item *
+
+'cursor_set', happens when the cursor position is changed.
 
 =back
 
-For complex things, L<here is the complete list|EVENT LIST> but read first L<EVENT NAMES AND LABELS>.
+For complex things, L<here is the complete list|/EVENT LIST> but read first L</EVENT NAMES AND LABELS>.
 
 =head2 'sub', 'use' and 'package' options of  one particular event in 'events' option
 
@@ -175,7 +187,7 @@ A hash reference that contains information relative to the event.
 =back
 
 Of course, you can't expect the information to be the same for a key press and for a mouse motion. The number and names of the hash keys 
-will then depend on the event itself. L<All keys are explained for each event here|EVENT LIST>. But it's easier to see all the possibilities for
+will then depend on the event itself. L<All keys are explained for each event here|/EVENT LIST>. But it's easier to see all the possibilities for
 the keys and guess what you'll get for your event :
 
 =over 4
@@ -217,10 +229,10 @@ But if you want you sub to be the last thing to be done in response to the event
     );
 
 In this case, your sub will B<always> be the last executed action. Sometimes, you would like to decide, according to the event information (so
-dynamically), if you want to go on or not. See here for L<dynamic exit|MORE ON 'ACTION' OPTION>.
+dynamically), if you want to go on or not. See here for L<dynamic exit|/MORE ON 'ACTION' OPTION>.
 
 In a more vicious way, you may want to change the values of the event information in order to change the data on which the default management
-will work. Again, the L<'action' option|MORE ON 'ACTION' OPTION> gives you the power to lie.
+will work. Again, the L<'action' option|/MORE ON 'ACTION' OPTION> gives you the power to lie.
 
 A good easy thing would be that if 'action' option (with 'exit value) is present without the 'sub' option, then nothing is executed, just an exit is made :
 
@@ -235,7 +247,7 @@ As you see, 'sub' option is, in fact, not mandatory.
 =head2 easy things conclusion
 
 Nothing has been said about threads and dynamic event linking, but this is quite normal for the easy part of the interface.
-Still you can do most of what has been introduced at L<the beginning|INTRODUCTION>.
+Still you can do most of what has been introduced at L<the beginning|/INTRODUCTION>.
 
 In an easy way, all events are done synchronously by the 'Graphic' thread : the 'Graphic' thread will have to complete your sub. So you may
 feel desperate if you have a huge task to do in response to a user event and if you still want your application to remain responsive : which seems
@@ -345,7 +357,7 @@ We've seen the 'exit' value of 'action' option that ends the event management. T
 
 =item *
 
-'jump' to go straight to a precise L<event label|EVENT NAMES AND LABELS>
+'jump' to go straight to a precise L<event label|/EVENT NAMES AND LABELS>
 
 =back
 
@@ -439,7 +451,7 @@ can be saved as dynamic configuration and inquired later. Keeping 'jump' with 'c
 
 =head3 smallest possible 'jump'
 
-As you may L<link more than one sub|'MULTI-SUB' DECLARATION> to one event, the smallest possible jump is done when you give the label
+As you may L<link more than one sub|/'MULTI-SUB' DECLARATION> to one event, the smallest possible jump is done when you give the label
 following your own one (here the information hash should contain the same keys as those you have received). In this case, what you have jumped
 are the possible other subs that were linked to the same label event as yours, these subs should have been done after your own one (if no jump has
 been made).
@@ -467,14 +479,14 @@ events is that you can't know when they occur and how many. Suppose your code re
 moves his mouse from left to right of your editor, you can have more than 10 mouse motion events generated in one second. And a perfect
 response to the first event can be useless as soon as the second event has occured. Moreover, the 'Graphic' thread will send all asynchronous events
 to your thread, even if it is busy working. Events will stack in a queue if your thread can't manage them quickly. If your code makes, in the end,
-a graphical action visible by the user, there could be a long delay between the event and its visible action.
+a graphical action visible by the user, there could be a long delay between the last event and its visible action.
 And the user would consider your code as very slow. On the contrary, if you work in an interruptible way, that is, if you insert, from time to time,
 little code like that :
 
     return if (anything_for_me); # "me" stands for your thread executing your code
 
 the user could have the feeling that your code is very fast : this is because you empty your thread queue more quickly and thus decrease the delay
-between an event and your answer. But you should add this line (that is, check your thread queue) when you are in a proper
+between the last event and its answer. But you should add this line (that is, check your thread queue) when you are in a proper
 state : just imagine that there is really something for you and that your code will be stopped and executed another time from the start.
 
 The conclusion is :  "A good way to be fast is to give up useless tasks" and using more than one thread allows you to give up, so don't hesitate
@@ -509,7 +521,7 @@ but doesn't wait for its response.
 
 =head2 'create' option
 
-In the L<'thread' option example|'thread' option>, the thread had already been created, but if you use 'thread' option with a name that is unknown, a new thread
+In the L<'thread' option example|/'thread' option>, the thread had already been created, but if you use 'thread' option with a name that is unknown, a new thread
 will be created on the fly and will be named accordingly.
 
 On the contrary, if you have written a bad name by mistake, you may want to prevent this auto-creation. The 'create' options has 3 possible values :
@@ -549,10 +561,10 @@ So you don't have to use the 'create' option if you want an auto-creation and th
 Well, the benefit of threads seems to be brought only by asynchronous calls, but there is a reason why you could wish a synchronous call.
 You may want to initialize data in your thread while changing values for the default event management. And the initialized data will be used
 after the default management in an asynchronous way. So you don't have to share variables between threads just because you want some
-events to be synchronous : variable 'scope' can then be limited. Read carefully the L<deadlock possibility|deadlocks, 'pseudo' value for 'sync' option>
+events to be synchronous : variable 'scope' can then be limited. Read carefully the L<deadlock possibility|/deadlocks, 'pseudo' value for 'sync' option>
 if you use this option.
 
-This point is easier to understand when you know that, for instance, for a single mouse clic, you can L<manage up to 3 different events|EVENT NAMES AND LABELS>.
+This point is easier to understand when you know that, for instance, for a single mouse clic, you can L<manage up to 3 different events|/EVENT NAMES AND LABELS>.
 
 Now what about the 'sync' option with a 'false' value ?
 Well, you will force an asynchronous call and this could be used ... for the 'Graphic' thread ! This trick won't prevent you from freezing the user
@@ -676,7 +688,7 @@ the line you were expecting to work on !).
 =head1 'MULTI-SUB' DECLARATION
 
 You can link more than one sub to a single event. This can be interesting if you want to mix 
-L<synchronous and asynchronous responses|THREADS CONTRIBUTION> or just if you
+L<synchronous and asynchronous responses|/THREADS CONTRIBUTION> or just if you
 have 2 very different things to do and don't want to hide them in a bad named sub.
 
  my $editor = Text::Editor::Easy->new( 
@@ -774,10 +786,10 @@ alt_ctrl_shift_ (applications designed for pianists only !)
 
 =back
 
-The suffix is associated to a precise moment in the clic sequence, the prefix to the meta keys pressed during the clic. Here are 3 examples of
+The suffix is associated to a precise moment in the clic sequence, the prefix to the modifier keys pressed during the clic. Here are 3 examples of
 event label among the 27 possible :
 
-=over *
+=over 4
 
 =item *
 
@@ -793,7 +805,7 @@ alt_ctrl_after_clic
 
 =back
 
-A true mouse clic event generates 6 events as explained in L<EVENT NAMES AND LABELS>. In fact, if we include the default actions,
+A true mouse clic event generates 6 events as explained in L</EVENT NAMES AND LABELS>. In fact, if we include the default actions,
 there are 9 steps in a complete clic sequence :
 
 =over 4
@@ -808,7 +820,7 @@ there are 9 steps in a complete clic sequence :
 
 =item *
 
-'hard_clic' default management (if no meta key pressed or if label is 'hard_clic') : drag initiation for resize management
+'hard_clic' default management (if no modifier key pressed or if label is 'hard_clic') : drag initiation for resize management
 
 =item *
 
@@ -824,7 +836,7 @@ there are 9 steps in a complete clic sequence :
 
 =item *
 
-'clic' default management (if no meta key pressed or if label is 'clic') : set cursor position
+'clic' default management (if no modifier key pressed or if label is 'clic') : set cursor position
 
 =item *
 
@@ -836,17 +848,17 @@ there are 9 steps in a complete clic sequence :
 
 =back
 
-These 9 steps should be understood if you plan to use L<a 'jump' action|'jump' value>. For instance, if you are in a "${meta}hard_clic" event sub, the smallest
-jump you could do would be to give the label 'hard_clic' (you will have the default 'hard_clic' management executed even if a meta key is
+These 9 steps should be understood if you plan to use L<a 'jump' action|/'jump' value>. For instance, if you are in a "${meta}hard_clic" event sub, the smallest
+jump you could do would be to give the label 'hard_clic' (you will have the default 'hard_clic' management executed even if a modifier key is
 pressed). But you could end your sub giving the same label of your event, "${meta}hard_clic" : in this case, the default 'hard_clic' management 
-will be done as usual (that is, only if no meta key was pressed), then the default ${meta}hard_clic transformation will be done, followed by 'any_clic'
+will be done as usual (that is, only if no modifier key was pressed), then the default ${meta}hard_clic transformation will be done, followed by 'any_clic'
 events and so on...
 
 Parameters received by your specific sub and needed at specific labels depends only on the suffix. So only suffixes are described.
 
 =head3 'hard_clic' suffix
 
-First couple of events generated in the 'clic' sequence. There is a default management (when no meta key is pressed) which initiates a drag 
+First couple of events generated in the 'clic' sequence. There is a default management (when no modifier key is pressed) which initiates a drag 
 sequence if the cursor shape is a resize arrow (in this particular case, nothing is done afterwards : no 'clic' and 'after_clic' management).
 
 The information received by your sub is a hash containing the following keys :
@@ -863,11 +875,11 @@ The information received by your sub is a hash containing the following keys :
 
 =item *
 
-'meta_hash', hash containing the keys 'alt', 'ctrl' and 'shift' : values are true if the corresponding meta key was pressed.
+'meta_hash', hash containing the keys 'alt', 'ctrl' and 'shift' : values are true if the corresponding modifier key was pressed.
 
 =item *
 
-'meta', string containing the meta key combination ('', 'shift_', 'alt_ctrl_', ...)
+'meta', string containing the modifier key combination ('', 'shift_', 'alt_ctrl_', ...)
 
 =back
 
@@ -877,7 +889,7 @@ The information received by your sub is a hash containing the following keys :
     {
         'file'   => 'my_file.t3d',
         'events' => {
-            'any_hard_clic' => {              # hard_clic for any meta key combination
+            'any_hard_clic' => {              # hard_clic for any modifier key combination
                 'sub'    => 'my_hard_clic_sub',
             },                         
         }                                     # end of events declaration
@@ -897,7 +909,7 @@ The information received by your sub is a hash containing the following keys :
 
 =head3 'clic' suffix
 
-Second couple of events generated in the 'clic' sequence. There is a default management  (when no meta key is pressed) which makes the 
+Second couple of events generated in the 'clic' sequence. There is a default management  (when no modifier key is pressed) which makes the 
 following actions :
 
 =over 4
@@ -934,11 +946,11 @@ The information received by your sub is a hash containing the following keys :
 
 =item *
 
-'meta_hash', hash containing the keys 'alt', 'ctrl' and 'shift' : values are true if the corresponding meta key was pressed : interesting for 'any_clic' event
+'meta_hash', hash containing the keys 'alt', 'ctrl' and 'shift' : values are true if the corresponding modifier key was pressed : interesting for 'any_clic' event
 
 =item *
 
-'meta', string containing the meta key combination ('', 'shift_', 'alt_ctrl_', ...) :  interesting for 'any_clic' event
+'meta', string containing the modifier key combination ('', 'shift_', 'alt_ctrl_', ...) :  interesting for 'any_clic' event
 
 =back
 
@@ -959,16 +971,35 @@ The information received by your sub is a hash containing the following keys (th
 
 =item *
 
-'meta_hash', hash containing the keys 'alt', 'ctrl' and 'shift' : values are true if the corresponding meta key was pressed (for 'any_after_clic')
+'meta_hash', hash containing the keys 'alt', 'ctrl' and 'shift' : values are true if the corresponding modifier key was pressed (for 'any_after_clic')
 
 =item *
 
-'meta', string containing the meta key combination ('', 'shift_', 'alt_ctrl_', ...),  for 'any_after_clic'
+'meta', string containing the modifier key combination ('', 'shift_', 'alt_ctrl_', ...),  for 'any_after_clic'
 
 =back
 
 =head2 'motion' subset
 
+=head1 EVENTS LINKED TO A ZONE INSTANCE
+
+Events can be linked to a L<'zone' instance|Text::Editor::Easy::Zone> rather than to a 
+'Text::Editor::Easy' instance.
+
+2 events are acessible for a 'zone' instance :
+
+=over 4
+
+=item *
+
+top_editor_change : happens each time a new 'editor' instance is on top of the zone.
+
+=item *
+
+editor_destroy : happens each time a 'editor' instance belonging to the zone is destroyed.
+
+=back
+
 =head1 CONCLUSION
 
 Maybe the interface seems a little complex in the end, still complexity have not been added freely. If this interface is adapted to programs
@@ -1001,11 +1032,6 @@ use threads;
 use Text::Editor::Easy::Comm;
 use Devel::Size qw(size total_size);
 
-my %ref_init;
-my %referenced;
-
-my %thread_known;
-
 use constant {
     SUB_REF => 0,
     PACKAGE => 1, 
@@ -1014,7 +1040,7 @@ use constant {
 };
 
 sub reference_events {
-    my ( $unique_ref, $events_ref ) = @_;
+    my ( $id, $events_ref ) = @_;
     
     # print "Dans reference_events events = $events_ref\n";
     if ( ! ref $events_ref or ref $events_ref ne 'HASH' ) {
@@ -1025,7 +1051,7 @@ sub reference_events {
         my $event_list_ref = $events_ref->{$event_name};
         if ( ref $event_list_ref eq 'HASH' ) {
             #print "Single event declaration\n";
-            my $answer = reference_event($unique_ref, $event_list_ref);
+            my $answer = reference_event($id, $event_list_ref);
             if ( ! ref $answer ) {
                 return if ( $answer eq 'error' );
                 delete $events_ref->{$event_name};
@@ -1042,7 +1068,7 @@ sub reference_events {
             #print "Multiple event declaration\n";
             my @new_list;
             while ( my $event_ref = shift @$event_list_ref ) {
-                my $answer = reference_event($unique_ref, $event_ref);
+                my $answer = reference_event($id, $event_ref);
                 if ( ! ref $answer ) {
                     return if ( $answer eq 'error' );
                 }
@@ -1060,6 +1086,7 @@ my %possible_action = (
     'exit'    => 1,
     'change' => 1,
     'jump'    => 1,
+    'nop'      => 1,
 );
 
 my %possible_sync = (
@@ -1070,7 +1097,7 @@ my %possible_sync = (
 
 
 sub reference_event {
-    my ( $unique_ref, $event_ref ) = @_;
+    my ( $id, $event_ref ) = @_;
     
     my $package = 'main';
     #print "REF de event_ref : ", ref $event_ref, "\n";
@@ -1086,22 +1113,31 @@ sub reference_event {
         }
     }
     my $action = $event_ref->{'action'};
-    if ( defined $action and ! $possible_action{$action} ) {
-        print STDERR "Unkown action value $action, instance not created\n";
-        return 'error';
+    if ( defined $action ) {
+        #print "Action dfinie  $action pour event_ref = $event_ref\n";
+        if ( ! $possible_action{$action} ) {
+            print STDERR "Unknown action value $action, instance not created\n";
+            return 'error';
+        }
     }
     my $sync = $event_ref->{'sync'};
     if ( defined $sync and ! $possible_sync{$sync} ) {
-        print STDERR "Unkown sync value $sync, instance not created\n";
+        print STDERR "Unknown sync value $sync, instance not created\n";
         return 'error';
     }
 
+    if ( ! defined $event_ref->{'package'} ) {
+        $event_ref->{'package'} = $package;
+    }
+    else { # A supprimer
+        $package = $event_ref->{'package'};
+    }
     if ( defined $thread ) {
-        my $answer_ref = thread_use( $unique_ref, $thread, $use, $event_ref->{'create'} );
+        my $answer_ref = thread_use( $id, $thread, $use, $event_ref->{'create'}, $event_ref->{'init'}, $package );
         return $answer_ref if ( ! ref $answer_ref );
         $event_ref->{'tid'} = $answer_ref->{'tid'};
         if ( $action ) {
-            if ( $action ne 'exit' ) {
+            if ( $action ne 'exit' and $action ne 'nop' ) {
                 if ( ! defined $sync or $sync eq 'false' ) {
                     print STDERR "Action $action forbidden with asynchronous call to thread $thread\n";
                     delete $event_ref->{'action'};
@@ -1109,20 +1145,50 @@ sub reference_event {
             }
         }
     }
-    if ( ! defined $event_ref->{'package'} ) {
-        $event_ref->{'package'} = $package;
+    
+    my $sub_ref = $event_ref->{'sub'};
+    if ( defined $sub_ref ) {
+        my $sub = ref $sub_ref;
+        if ( $sub ) {
+            if ( $sub ne 'ARRAY' ) {
+                print STDERR "'sub' option in 'event' declaration should be a string or an array reference\n";
+                return 'error';
+            }
+            $sub = $sub_ref;
+        }
+        else {
+            $sub = [ $sub_ref ];
+        }
+        $event_ref->{'sub'} = $sub;
+        return $event_ref;
+    }
+
+    $event_ref->{'sub'} = [ ];
+    
+    if ( ! defined $action ) {
+        print STDERR "No action defined and no sub provided, event cancelled\n";
+        return 'unlink';
+    }
+    return $event_ref if ( $action eq 'exit' );
+    if ( $action ne 'nop' ) {
+        print STDERR "Action $action not correct when no sub is provided, event cancelled\n";
+        return 'unlink';
+    }
+    if ( ! defined $thread ) {
+        print STDERR "Action nop should be linked with a thread option, event cancelled\n";
+        return;
     }
     #print "Pour event $event_ref package = $package\n";
     return $event_ref;
 }
 
 sub thread_use {
-    my ( $unique_ref, $thread, $use, $create ) = @_;
+    my ( $id, $thread, $use, $create, $init, $package ) = @_;
 
     my $tid = $thread;
     if ( $thread =~ /\D/ ) {
-        $tid = Text::Editor::Easy::Comm::get_tid_from_name_and_instance( $unique_ref, $thread );
-		$tid = 0 if ( $thread eq 'Graphic' );
+        $tid = Text::Editor::Easy::Comm::get_tid_from_name_and_instance( $id, $thread );
+        $tid = 0 if ( $thread eq 'Graphic' );
         if ( ! defined $tid and $thread ne 'File_manager' ) {
             if ( defined $create ) {
                 if ( $create eq 'warning' ) {
@@ -1145,16 +1211,22 @@ sub thread_use {
         }
     }
     if ( defined $tid ) {
-        Text::Editor::Easy->ask_thread( 'use_module', $tid, 'Text::Editor::Easy::Events' );
+        Text::Editor::Easy::Async->ask_thread( 'use_module', $tid, 'Text::Editor::Easy::Events' );
         if ( defined $use ) {
-            Text::Editor::Easy->ask_thread( 'use_module', $tid, $use );
+            Text::Editor::Easy::Async->ask_thread( 'use_module', $tid, $use );
+        }
+        if ( defined $init and ref $init eq 'ARRAY' ) {
+            my @init = @$init;
+            my $sub = shift @init;
+            #print "Avant appel $sub : package = $package\n";
+            Text::Editor::Easy::Async->ask_thread( $sub, $tid, @init );
         }
     }
     return { 'tid' => $tid }; # $tid maybe undef
 }
 
 sub execute_events {
-    my ( $events_ref, $editor, $info_ref ) = @_;
+    my ( $events_ref, $object, $info_ref ) = @_;
 
     my $events_list_ref;
     
@@ -1173,9 +1245,17 @@ sub execute_events {
     
     EVENT: for my $event ( @$events_list_ref ) {
         my $action = $event->{'action'};
-        my $new_info_ref = execute_event($event, $editor, $info_ref);
-        next EVENT if ( ! defined $action );
+        #print "Event $event\n";
+        #if ( ! defined $action ) {
+        #    print "    ... action non dfinie pour objet = ", $object->name, "\n";
+        #}
+        #else {
+        #    print "    ... action $action\n";
+        #}
+        my $new_info_ref = execute_event($event, $object, $info_ref);
+        next EVENT if ( ! defined $action or $action eq 'nop' );
         return if ( $action eq 'exit' );
+
         #print "Dans execute_events action = $action\n";
         #print "   ...ref de new_info_ref : ", ref( $new_info_ref ), "\n";
         if ( ! defined $new_info_ref or ! ref $new_info_ref ) {
@@ -1205,53 +1285,78 @@ sub execute_events {
 
 sub execute_event {
     my ( $event_ref, $editor, $info_ref ) = @_;
-    
+
     my $package = $event_ref->{'package'};
-    my $sub = $event_ref->{'sub'};
+    my ( $sub, @user ) = @{$event_ref->{'sub'}};
     #print "EXECUTE_EVENT : PAckage $package, sub = $sub\n";
     my $action = $event_ref->{'action'};
     if ( ! defined $sub ) {
-        if ( $action eq 'exit' ) {
-            return;
+        if ( defined $action ) {
+            return if ( $action eq 'exit' );
+            if ( $action eq 'nop' ) {
+                #print "Avant excution d'une action nop pour ", $editor->name, "\n";
+                thread_nop( $editor, $event_ref );
+                return;
+            }
         }
     }    
     my $thread = $event_ref->{'thread'};
     if ( defined $thread ) {
         #print "Appel de thread execute avec thread = $thread\n";
-        return thread_execute( $thread, $event_ref, $editor, $info_ref, $package, $sub );
+        #if ( ! defined $action ) {
+        #    print "1 Avant appel transform and execute pour thread : action = undef\n";
+        #}
+        #else {
+        #    print "1 Avant appel transform and execute pour thread : action = $action\n";
+        #}
+        return thread_execute( $thread, $event_ref, $editor, $info_ref, $package, $sub, @user );
     }
     else  {
         my $sync = $event_ref->{'sync'};
         if ( defined $sync and $sync eq 'false' ) {
             $event_ref->{'tid'} = 0;
             #print "Avant thread_execute pour tid = 0\n";
-            return thread_execute( $thread, $event_ref, $editor, $info_ref, $package, $sub );
+            #print "2 Avant appel transform and execute pour thread : action = $action\n";
+            return thread_execute( $thread, $event_ref, $editor, $info_ref, $package, $sub, @user );
         }
-        my $answer = transform_and_execute( $editor, $info_ref, $package, $sub );
+        my $answer = transform_and_execute( $editor, $info_ref, $package, $sub, @user );
         #print "Dans execute_event ref de answer = ", ref( $answer ), "\n";
         return untransform( $answer, $action );
     }
 }
 
 sub thread_execute {
-    my ( $thread, $event_ref, $editor, $info_ref, $package, $sub ) = @_;
+    my ( $thread, $event_ref, $object, $info_ref, $package, $sub, @user ) = @_;
 
     my $tid = $event_ref->{'tid'};
-    my $unique_ref = $editor->get_ref;
+    
+    my $type = ref $object;  
+    my $id = '';
+    if ( $type eq 'Text::Editor::Easy' ) {
+        $id = $object->id;
+    }
     if ( ! defined $tid ) {
         if ( $thread ne 'File_manager' ) {
             print STDERR "Can't execute event : unknown tid for thread $thread\n";
             return;
         }
         else {
-            $tid = Text::Editor::Easy::Comm::get_tid_from_name_and_instance( $unique_ref, 'File_manager' );
+            $tid = Text::Editor::Easy::Comm::get_tid_from_name_and_instance( $id, 'File_manager' );
             #print "Rcupr le tid $tid pour le thread File_manager\n";
             # Utiliser l'interface dynamique pour modifier l'vnement... ?
         }
     }
+    my $object_ref;
+    if ( $id eq '' ) {
+        $object_ref = [ $type, $object ];
+    }
+    else {
+        $object_ref = [ 'Text::Editor::Easy', $id ];
+    }
+    
     my $sync = $event_ref->{'sync'};
     my $sub_name = 'Text::Editor::Easy::Events::thread_transform';
-    my @param = ( $sub_name, $tid, $unique_ref, $package, $sub, $info_ref, $event_ref->{'action'} );
+    my @param = ( $sub_name, $tid, $object_ref, $package, $sub, $info_ref, $event_ref->{'action'}, @user );
     $sync = 'false' if ( ! defined $sync );
     if ( $sync eq 'true' ) {
         return Text::Editor::Easy->ask_thread( @param );
@@ -1269,43 +1374,88 @@ sub thread_execute {
     }
     else {
         #print "Appel en asynchrone pour tid = $tid\n";
-        Text::Editor::Easy::Async->ask_thread( @param );
-        
+        Text::Editor::Easy::Async->ask_thread( @param );        
     }        
 }
 
-my %editor;
+sub thread_nop {
+    my ( $editor, $event_ref ) = @_;
+        
+    my $tid = $event_ref->{'tid'};
+
+    my $type = ref $editor;  
+    my $id = '';
+    if ( $type eq 'Text::Editor::Easy' ) {
+        $id = $editor->id;
+    }
+    
+    if ( ! defined $tid ) {
+        if ( $event_ref->{'thread'} ne 'File_manager' ) {
+            print STDERR "Can't execute event : unknown tid for thread $event_ref->{'thread'}\n";
+            return;
+        }
+        else {
+            $tid = Text::Editor::Easy::Comm::get_tid_from_name_and_instance( $id, 'File_manager' );
+            #print "Rcupr le tid $tid pour le thread File_manager\n";
+            # Utiliser l'interface dynamique pour modifier l'vnement... ?
+        }
+    }
+    my $sub_name = 'Text::Editor::Easy::Events::nop';
+    my @param = ( $sub_name, $tid );
+    Text::Editor::Easy::Async->ask_thread( @param );
+}
+
+sub nop {
+    my ( $self, $reference ) = @_;
+    
+    #print "Dans nop, thread = ", threads->tid, ", self = $self, reference = $reference\n";
+    return;
+}
 
 sub thread_transform {
-    my ( $self, $ref, $unique_ref, $package, $sub, $info_ref, $action ) = @_;
+    my ( $self, $ref, $object_ref, $package, $sub, $info_ref, $action, @user ) = @_;
     
-    my $editor = $editor{$unique_ref};
-    if ( ! defined $editor ) {
-        $editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
-        Text::Editor::Easy::Comm::set_ref( $editor, $unique_ref);
-        $editor{$unique_ref} = $editor;
+    my $object;
+    if ( $object_ref->[0] ne 'Text::Editor::Easy' ) {
+        # Cas  grer 
+        # $object = $type -> get_from_id;  ==> $type eq 'Text::Editor::Easy' ou 'Text::Editor::Easy::Zone' ou '...Window' ou ...
+        $object = $object_ref->[1];
     }
+    else {
+        $object = Text::Editor::Easy->get_from_id( $object_ref->[1] );
+    }
+    
     #print "Appel transform_and_execute pour tid = ", threads->tid, "\n";
-    my $answer = transform_and_execute( $editor, $info_ref, $package, $sub);
+    my $answer = transform_and_execute( $object, $info_ref, $package, $sub, @user);
     return untransform( $answer, $action );
 }
 
 sub transform_and_execute {
-    my ( $editor, $info_ref, $package, $sub ) = @_;
+    my ( $editor, $info_ref, $package, $sub, @user ) = @_;
 
-    my $ref_line = $info_ref->{'line'};
-    if ( defined $ref_line ) {
-        my $line = Text::Editor::Easy::Line->new( $editor, $ref_line, );
-        $info_ref->{'line'} = $line;
-    }
-    my $ref_display = $info_ref->{'display'};
-    if ( defined $ref_display ) {
-        my $display =
-          Text::Editor::Easy::Display->new( $editor, $ref_display, );
-        $info_ref->{'display'} = $display;
+    KEY: for my $key ( keys %$info_ref ) {
+        if ( $key eq 'line' ) {
+            my $line = Text::Editor::Easy::Line->new( $editor, $info_ref->{'line'} );
+            $info_ref->{'line'} = $line;
+            next KEY;
+        }
+        if ( $key eq 'display' ) {
+            my $display = Text::Editor::Easy::Display->new( $editor, $info_ref->{'display'} );
+            $info_ref->{'display'} = $display;
+            next KEY;
+        }
+        if ( $key =~ /editor$/ ) {
+            my $value = $info_ref->{$key};
+            if ( defined $value ) {
+                my $editor = Text::Editor::Easy->get_from_id( $info_ref->{$key} );
+                $info_ref->{$key} = $editor;
+            }
+            next KEY;
+        }
     }
+    
     no strict "refs";
-    return &{"${package}::$sub"}( $editor, $info_ref );
+    return &{"${package}::$sub"}( $editor, $info_ref, @user );
 }
 
 sub untransform {
@@ -1369,6 +1519,9 @@ under the same terms as Perl itself.
 
 
 
+
+
+
 
 
 
