@@ -10,11 +10,11 @@ user modification in the Eval tab of the Editor.pl program.
 
 =head1 VERSION
 
-Version 0.44
+Version 0.46
 
 =cut
 
-our $VERSION = '0.44';
+our $VERSION = '0.46';
 
 use Text::Editor::Easy::Comm;
 
@@ -23,10 +23,11 @@ my $eval_thread;
 my $eval_print;
 
 sub init_eval {
-    my ( $self, $reference, $other_ref, $unique_ref ) = @_;
-    #print "============>INIT de Search .. $self, $unique_ref\n";
-    $out = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
-    Text::Editor::Easy::Comm::set_ref( $out, $unique_ref);
+    my ( $self, $reference, $id ) = @_;
+    
+    print "Dans init_eval de Search.pm .. $self, $id\n";
+    
+    $out = Text::Editor::Easy->get_from_id( $id );
 
     #$out->insert('Bonjour');
     #$self, $package, $tab_methods_ref, $self_server
@@ -39,7 +40,10 @@ sub init_eval {
         }
     );
 
-    #print "EVAL _TJREAD = $eval_thread\n";
+    print "EVAL _TJREAD = $eval_thread\n";
+    #print "Appel idle_eval_exec en asynchrone...\n";
+    #Text::Editor::Easy::Async->idle_eval_exec("toto");
+    #print "Appel exec_eval en synchrone ...\n";
     #Text::Editor::Easy->exec_eval('Bonjour');
 
     $eval_print = Text::Editor::Easy->create_new_server(
@@ -50,7 +54,7 @@ sub init_eval {
             'object'  => [],
             'init'    => [
                 'Text::Editor::Easy::Program::Eval::Print::init_print_eval',
-                $unique_ref
+                $id
             ],
         }
     );
@@ -68,10 +72,11 @@ sub init_eval {
 }
 
 sub modify_pattern {
-    my ( $unique_ref, $editor, $hash_ref ) = @_;
+    my ( $editor ) = @_;
+
+    print "Dans modify_pattern de Search.pm\n";
 
     #return;
-    #print "Dans modify_pattern...$hash_ref->{'text'}\n";
     Text::Editor::Easy::Async->idle_eval_exec($eval_print);
     return if ( anything_for_me() );
     my $line = $editor->first;
@@ -104,8 +109,9 @@ sub modify_pattern {
     $out->empty;
     return if ( anything_for_me() );
 
-    $out->async->on_top;
-    Text::Editor::Easy::Async->exec_eval($program, $hash_ref);
+    #$out->async->on_top;
+    $out->async->make_visible;
+    Text::Editor::Easy::Async->exec_eval($program);
     return;
 }
 
@@ -134,8 +140,7 @@ sub search {
 
     print "IND $ind, EXP $exp\n";
     my @search = Text::Editor::Easy->list_in_zone('zone1');
-    my $search = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
-    Text::Editor::Easy::Comm::set_ref( $search, $search[$ind] );
+    my $search = Text::Editor::Easy->get_from_id( $search[$ind] );
 
     # Recherche dans l'cran
     return if ( anything_for_me() );
