@@ -9,11 +9,11 @@ Text::Editor::Easy::Program::Tab - Tab simulation with a Text::Editor::Easy obje
 
 =head1 VERSION
 
-Version 0.44
+Version 0.46
 
 =cut
 
-our $VERSION = '0.44';
+our $VERSION = '0.46';
 
 use Text::Editor::Easy::Comm;
 
@@ -21,35 +21,38 @@ use File::Basename;
 
 use Data::Dump qw(dump);
 
-my %tab_object;
-
 sub on_main_editor_change {
-    my $name = on_top_editor_change(@_);
-    #print "On main editor change : $name\n";
-    $_[0]->change_title($name);
+    my ( $zone, $info_ref, @user ) = @_;
+    
+    my $name = on_top_editor_change( $zone, $info_ref, @user );
+    #print "On main editor change : $name, zone = $zone->{'name'}\n";
+    $info_ref->{'editor'}->change_title($name);
     #print "Aprs changement de nom\n";
 }
 
 sub on_top_editor_change {
-    my ( $new_on_top_editor, $tab_ref, $hash_ref, $old_on_top_editor, $conf_ref ) = @_;
+    my ( $zone, $info_ref, $tab_ref ) = @_;
 
-#print "Nom du nouveau fichier on_top : |", $new_on_top_editor->file_name, "|\n";
-    my $tab_editor = $tab_object{$tab_ref};
-    if ( !$tab_editor ) {
-        #print "Cration locale l'diteur correspondant au Tab $tab_ref\n";
-        $tab_editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
-        Text::Editor::Easy::Comm::set_ref( $tab_editor, $tab_ref);
-        $tab_object{$tab_ref} = $tab_editor;
-        # Il faudrait ajouter une mthode supplmentaire pour le Tab : la mthode qui met  jour save_info (cl "file_list")
-        # ==> cette mthode ne doit pas tre partage par tous les objets Text::Editor::Easy (nouvel objet Tab, hritage  voir)
-    }
+    #print "Dans on_top_editor_change : tab_ref = $tab_ref\n";
+
+    my $new_on_top_editor = $info_ref->{'editor'};
+    my $hash_ref          = $info_ref->{'hash_ref'};
+    
+    my $old_on_top_editor = $info_ref->{'old_editor'};
+    my $conf_ref          = $info_ref->{'conf'};
+    
+
+    #print "Nom du nouveau fichier on_top : |", $new_on_top_editor->file_name, "|\n";
+    
+    my $tab_editor = Text::Editor::Easy->get_from_id ( $tab_ref );
+    
     if ( defined $old_on_top_editor ) {
         my $name = $old_on_top_editor->name;
         #print "\n\nDans on_top_editor_change de Tab : old_editor => $name\n";
-        Text::Editor::Easy::Async->update_conf ( $old_on_top_editor->get_ref, $conf_ref, $name );
+        Text::Editor::Easy::Async->update_conf ( $old_on_top_editor->id, $conf_ref, $name );
     }
 
-    #$tab_editor->async->select_new_on_top ( $new_on_top_editor->get_ref, $tab_ref, $hash_ref );
+    #$tab_editor->async->select_new_on_top ( $new_on_top_editor->id, $tab_ref, $hash_ref );
     my ( $absolute_path, $file_name, $relative_path, $full_absolute, $full_relative, $name )
             = $new_on_top_editor->file_name;
 
@@ -60,7 +63,7 @@ sub on_top_editor_change {
     # dselection, slection, ...)
     
     # Ancien appel asynchrone
-            #$tab_editor->async->select_new_on_top ( $new_on_top_editor->get_ref, $tab_ref, $hash_ref, 
+            #$tab_editor->async->select_new_on_top ( $new_on_top_editor->id, $tab_ref, $hash_ref, 
             #    $absolute_path, $file_name, $relative_path, $full_absolute, $full_relative, $name );
     # Nouvel appel asynchrone
     select_new_on_top_thread_0 ( $tab_editor, $new_on_top_editor, $hash_ref, 
@@ -70,9 +73,9 @@ sub on_top_editor_change {
 }
 
 sub motion_over_tab {
-    my ( $unique_ref, $editor, $hash_ref ) = @_;
+    my ( $editor, $hash_ref ) = @_;
 
- #print "Dans motion_over_tab $unique_ref|$editor|", $hash_ref->{'line'}, "|\n";
+    #print "Dans motion_over_tab $editor|", $hash_ref->{'line'}, "|\n";
   # Vrification que l'on est bien sur la premire ligne
     return if ( anything_for_me() );
 
@@ -84,7 +87,7 @@ sub motion_over_tab {
     my $pointed_line = $hash_ref->{'line'};
     return if ( $first_line != $pointed_line );
 
-    my $pos = $hash_ref->{'line_pos'};
+    my $pos = $hash_ref->{'pos'};
 
     return if ( anything_for_me() );
     my $info_ref = $editor->load_info;
@@ -139,7 +142,12 @@ sub new_on_top {
    #print "Cration d'un diteur par motion sur tab : ", dump ($file_ref), "\n";
         return if ( !$file_ref->{'zone'} );
         $file_ref->{'focus'} = 'yes';
-
+        $file_ref->{'events'} = {
+            'motion' => { 
+                'action' => 'nop',
+                'thread' => 'Motion',
+            },
+        };
         #$new_on_top = Text::Editor::Easy->new($file_ref);
 
 # Appel asynchrone obligatoire : la cration d'un diteur peut obliger le thread 0  appeler le thread motion
@@ -162,18 +170,10 @@ sub new_on_top {
 }
 
 sub on_editor_destroy {
-    my ( $destroyed_editor, $tab_ref, $hash_ref ) = @_;
+    my ( $zone, $hash_ref, $tab_ref ) = @_;
 
     my $destroyed = $hash_ref->{'name'};
-    my $tab_editor = $tab_object{$tab_ref};
-    if ( !$tab_editor ) {
-        print "Cration locale l'diteur correspondant au Tab $tab_ref\n";
-        $tab_editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
-        Text::Editor::Easy::Comm::set_ref( $tab_editor, $tab_ref);
-        $tab_object{$tab_ref} = $tab_editor;
-        # Il faudrait ajouter une mthode supplmentaire pour le Tab : la mthode qui met  jour save_info (cl "file_list")
-        # ==> cette mthode ne doit pas tre partage par tous les objets Text::Editor::Easy (nouvel objet Tab, hritage  voir)
-    }
+    my $tab_editor = Text::Editor::Easy->get_from_id( $tab_ref );
     my $info_ref      = $tab_editor->load_info;
     my $file_list_ref = $info_ref->{'file_list'};
     my $selected = $info_ref->{'selected'};
@@ -252,12 +252,15 @@ sub select_new_on_top_thread_0 {
         $hash_ref->{'full_absolute'} = $full_absolute;
         $hash_ref->{'file'} = $full_relative if ( defined $full_relative );
         $hash_ref->{'name'} = $name;
-        push @$file_list_ref, $hash_ref;
-        #print "Dans select_new_on_top : Ajout d'un nouvel diteur : zone => ", $hash_ref->{'zone'}, "\n";
         my $zone_ref = $hash_ref->{'zone'};
         if ( ref $zone_ref ) {
             $hash_ref->{'zone'} = $zone_ref->{'name'};
-        }
+        }        
+        #print "Dans select_new_on_top : Ajout d'un nouvel diteur : zone => ", $hash_ref->{'zone'}, "\n";
+        #print "Avant sauvegarder par save_info, highlight = \n", dump ( $hash_ref->{'highlight'} ),
+        #    "\nEVENTS = \n", dump ( $hash_ref->{'events'} ), "\n";
+        push @$file_list_ref, $hash_ref;
+        
         $info_ref->{'selected'} = scalar (@$file_list_ref) - 1;
     }
     #print "DUMP\n", dump ($file_list_ref), "FIN DUMP\n";
@@ -271,8 +274,7 @@ sub select_new_on_top_thread_0 {
 sub update_conf {
     my ( $self, $ref_old_on_top_editor, $conf_ref, $old_name ) = @_;
     
-    my $old_editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
-    Text::Editor::Easy::Comm::set_ref( $old_editor, $ref_old_on_top_editor);
+    my $old_editor = Text::Editor::Easy->get_from_id( $ref_old_on_top_editor );
     
     # Text::Editor::Easy::Program::Tab n'a pas t "valu" par File_manager => il faudrait grer l'valuation automatique dans Comm...
     
@@ -284,8 +286,10 @@ sub update_conf {
     #    "\$info_old_editor_ref->{'first_line_ref'} = ", $info_old_editor_ref->{'first_line_ref'},
     #    "\n\$info_old_editor_ref->{'cursor_line_ref'} = ", $info_old_editor_ref->{'cursor_line_ref'}, "\n";
     my $load_info_ref = Text::Editor::Easy::File_manager::load_info( $self );
+    #print "Load info de Tab = \n", dump( $load_info_ref ), "\n";
     my $file_list_ref = $load_info_ref->{'file_list'};
     my ( $text, $indice, $start, $end ) = search_position ( $file_list_ref, $old_name );
+    #print "Dans update_conf : texte = $text, indice = $indice, start = $start, end = $end\n";
     if ( defined $indice ) {
         my $info_ref = $file_list_ref->[$indice];
         my ( $absolute_path, $file_name, $relative_path, $full_absolute, $full_relative, $name )
@@ -295,17 +299,19 @@ sub update_conf {
             $info_ref->{'absolute_path'} = $absolute_path;
             $info_ref->{'full_relative'} = $full_relative;
             $info_ref->{'full_absolute'} = $full_absolute;
-			if ( defined $full_relative ) {
+            if ( defined $full_relative ) {
                 $info_ref->{'file'} = $full_relative;
-		    }
-			elsif ( defined $full_absolute ) {
-				$info_ref->{'file'} = $full_absolute;
-		    }
-			else {
-				$info_ref->{'file'} = $file_name;
-		    }
+            }
+            elsif ( defined $full_absolute ) {
+                $info_ref->{'file'} = $full_absolute;
+            }
+            else {
+                $info_ref->{'file'} = $file_name;
+            }
         }
         $info_ref->{'config'} = $info_old_editor_ref;
+        print "Avant appel mthode zone\n";
+        $info_ref->{'zone'} = $old_editor->zone;
     }
     return $load_info_ref;
 }
@@ -331,14 +337,7 @@ sub select_new_on_top {
     my $file_list_ref = $info_ref->{'file_list'};
     my ( $text, $indice, $start, $end ) = search_position ( $file_list_ref, $name );
     my ( $first_ref, $first_text ) = Text::Editor::Easy::File_manager::next_line( $self );
-    my $tab_editor = $tab_object{$tab_ref};
-    if ( !$tab_editor ) {
-        $tab_editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
-        Text::Editor::Easy::Comm::set_ref( $tab_editor, $tab_ref);
-        $tab_object{$tab_ref} = $tab_editor;
-        # Il faudrait ajouter une mthode supplmentaire pour le Tab : la mthode qui met  jour save_info (cl "file_list")
-        # ==> cette mthode ne doit pas tre partage par tous les objets Text::Editor::Easy (nouvel objet Tab, hritage  voir)
-    }
+    my $tab_editor = Text::Editor::Easy->get_from_id( $tab_ref );
     $tab_editor->async->deselect;
 
     if ( defined $indice ) {
@@ -364,7 +363,7 @@ sub select_new_on_top {
         $hash_ref->{'file'} = $full_relative || $full_absolute;
         $hash_ref->{'name'} = $name;
         push @$file_list_ref, $hash_ref;
-        print "Dans select_new_on_top : Ajout d'un nouvel diteur : zone => ", $hash_ref->{'zone'}, "\n";
+        #print "Dans select_new_on_top : Ajout d'un nouvel diteur : zone => ", $hash_ref->{'zone'}, "\n";
         my $zone_ref = $hash_ref->{'zone'};
         if ( ref $zone_ref ) {
             $hash_ref->{'zone'} = $zone_ref->{'name'};
@@ -418,7 +417,7 @@ sub save_conf {
     
     my $old_editor = Text::Editor::Easy::Zone->whose_name('zone1')->on_top_editor;
     my $conf_ref = $old_editor->on_focus_lost();
-    update_conf( $self, $old_editor->get_ref, $conf_ref, $old_editor->name );
+    update_conf( $self, $old_editor->id, $conf_ref, $old_editor->name );
 
     open (INFO, ">$file" ) or die "Impossible d'ouvrir $file : $!\n";
     print INFO dump Text::Editor::Easy::File_manager::load_info( $self );
@@ -431,7 +430,7 @@ sub save_conf_thread_0 {
     #print "Dans save_conf_thread_0 : file = $file\n";
     my $old_editor = Text::Editor::Easy::Zone->whose_name('zone1')->on_top_editor;
     my $conf_ref = $old_editor->on_focus_lost();
-    return Text::Editor::Easy->update_conf( $old_editor->get_ref, $conf_ref, $old_editor->name );
+    return Text::Editor::Easy->update_conf( $old_editor->id, $conf_ref, $old_editor->name );
 }
 
 sub get_conf_for_absolute_file_name {
