@@ -9,14 +9,14 @@ Text::Editor::Easy::Syntax::Perl_glue - Perl highlighting (will always be limite
 
 =head1 VERSION
 
-Version 0.44
+Version 0.46
 
 =cut
 
-our $VERSION = '0.44';
+our $VERSION = '0.46';
 
-use Syntax::Highlight::Perl ':FULL';
-my $formatter = new Syntax::Highlight::Perl;
+use Syntax::Highlight::Perl::Improved ':FULL';
+my $formatter = new Syntax::Highlight::Perl::Improved;
 
 $formatter->define_substitution( 'Z' => 'Z&' );
 
